.. django-genericimports documentation master file, created by
   sphinx-quickstart on Wed Jan 21 11:26:44 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

django-genericimports's documentation!
======================================

django-genericimports is a django application to import CSV/XLS files into
your database without having to care about headers or data types, it provides
support for foreignkeys, callbacks, thirdparty fields, etc.

Contents:

.. toctree::
   :maxdepth: 2

   introduction
   featuresandrequirements
   installing
   configuration
   filtersandcallbacks
   reports

License
=======

This application is licensed in BSD 2-Clause license. This application was developed while at work on Havas Worldwide London, so part of the kudos goes to them as well.

.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`

